/*
//
// BEGIN SONGBIRD GPL
//
// This file is part of the Songbird web player.
//
// Copyright(c) 2005-2008 POTI, Inc.
// http://songbirdnest.com
//
// This file may be licensed under the terms of of the
// GNU General Public License Version 2 (the "GPL").
//
// Software distributed under the License is distributed
// on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either
// express or implied. See the GPL for the specific language
// governing rights and limitations.
//
// You should have received a copy of the GPL along with this
// program. If not, go to http://www.gnu.org/licenses/gpl.html
// or write to the Free Software Foundation, Inc.,
// 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
//
// END SONGBIRD GPL
//
 */

if (typeof Cc == 'undefined') var Cc = Components.classes;
if (typeof Ci == 'undefined') var Ci = Components.interfaces;
if (typeof Cu == "undefined") var Cu = Components.utils;
if (typeof Cr == 'undefined') var Cr = Components.results;

const PROPERTY_FILE = "chrome://daapclient/locale/daapclient.properties";


/* global variables -------------------------------------------------------*/
var ioService = null;
var daapLibManager = null;
var l10n = null;

var daapclientCreated = false;



/* functions --------------------------------------------------------------*/

function doLoad()
{

  // fill the textbox with the default url
  var urlTextbox  = document.getElementById("daapclient_dialognew_url");
  urlTextbox.value = "daap://";

  // focus the ok button by default
  document.documentElement.getButton("accept").focus();
}



function doOK()
{
  // Do nothing if the remote library has been already created
  if (daapclientCreated) {
    return true;
  }

  if (!(ioService instanceof Ci.nsIIOService)) { 
    ioService = Cc["@mozilla.org/network/io-service;1"].getService(Ci.nsIIOService);
  }

  if (!(l10n instanceof Ci.nsIStringBundle)) {
      l10n = Cc["@mozilla.org/intl/stringbundle;1"]
            .getService(Ci.nsIStringBundleService)
            .createBundle(PROPERTY_FILE);
  }

  if (!(daapLibManager instanceof Ci.sbIDaapLibraryManager)) {
    daapLibManager = Cc["@songbirdnest.com/daap/library-manager;1"]
                      .getService(Ci.sbIDaapLibraryManager);
  }    

  // Make sure the URL is valid
  let url = document.getElementById("daapclient_dialognew_url").value;
  let uri = null;
  try {
    uri = ioService.newURI(url, null, null);
  }
  catch (e) { }


  // explicitly disallow "daap://" as a valid URL
  if (url == "daap://") {
    uri = null;
  }

  // allow only daap's libraries
  if (uri && !uri.schemeIs("daap")) {
    uri = null;
  }

  // abort if we don't have a valid uri
  if (!uri) {
    gPrompt.alert(window, 
        l10n.GetStringFromName("DlgInvalidUrlTitle"),
        l10n.GetStringFromName("DlgInvalidUrlMessage")
        );
    return false;
  }


  let address = uri.host;
  let name = address;
  let port = uri.port;
  if (port == -1) {
    port = 3689;
  }
  else {
    name += "/"+port;
  }
  let id = "static_" + address + "_" + port;


  /* register the new library */
  daapLibManager.registerLibrary(id, name, address, port, true);
  

  // Indicate that the remote library has been created
  daapclientCreated = true;

  return true;
}



function doCancel()
{
  return true;
}

